@@ -7,14 +7,14 @@ test_that("datatypes-IO",{
 	if(file.exists(fname)) file.remove(fname)
 	dsetname <- c("testmat1", "testmat2")
 	
-	file <- new( "H5File", fname, "a")
+	file <- h5file(fname, "a")
 	group <- createGroup(file, "/testgroup")
 	dset <- createDataSet(group, dsetname[1], testmat)
 	h5close(dset)
 	h5close(group)
 	h5close(file)
 	
-	file <- new( "H5File", fname, "r")
+	file <- h5file(fname, "r")
 	group <- openGroup(file, "/testgroup")
 	dset <- openDataSet(group, dsetname[1], "double")
 	outmat <- readDataSet(dset)
@@ -23,7 +23,7 @@ test_that("datatypes-IO",{
 	h5close(group)
 	h5close(file)
 	
-	file <- new( "H5File", fname, "a")
+	file <- h5file(fname, "a")
 	group2 <- createGroup(file, "/testgroup/testgroup2")
 	dset2 <- createDataSet(group2, dsetname[2], testmat)
 	outmat2 <- readDataSet(dset2)
@@ -32,7 +32,7 @@ test_that("datatypes-IO",{
 	h5close(group2)
 	h5close(file)
 	
-	file2 <- new( "H5File", fname, "r")
+	file2 <- h5file(fname, "r")
 	group3 <- openGroup(file2, "/testgroup/testgroup2")
 	dset3 <- openDataSet(group3, dsetname[2], "double") 
 	outmat3 <- readDataSet(dset3)
@@ -41,6 +41,6 @@ test_that("datatypes-IO",{
 	h5close(group3)
 	h5close(file2)
 	
-	file.remove(fname)
+  expect_that(file.remove(fname), is_true())
 })
 
